// WARNING!!! DO NOT EDIT - FILE GENERATED BY APPLETGEN
#ifndef _WORDCOPYARM_H
#define _WORDCOPYARM_H

#include <stdint.h>

typedef struct
{
    uint32_t dst_addr;
    uint32_t reset;
    uint32_t src_addr;
    uint32_t stack;
    uint32_t start;
    uint32_t words;
    uint8_t code[52];
} WordCopyArm;

#endif // _WORDCOPYARM_H
